;
; 拡張トランジション(画面切り替え効果) プラグイン v1.03
; keito
;
; ＜導入すると、以下のトランジションが簡単に扱えます＞
;   1.クロスフェード
;   2.スライド
;   3.ズームイン / ズームアウト
;   4.ブラック(ホワイト)イン / ブラックアウト
;   5.爆発
;
;
; ＜使い方＞
;   最初に、ex_trans.ksを読み込んでください。
;   [call storage="ex_trans/ex_trans.ks"]
;
;   [ex_cross storage="rouka.jpg"]                 1.クロスフェード
;   [ex_slide storage="room.jpg"]                  2.スライド
;
;   [ex_zoomin storage="rouka.jpg"]                3.ズームイン
;   [ex_zoomout storage="room.jpg"]                3.ズームアウト
;
;   [ex_blackin storage="rouka.jpg"]               4.ブラックイン
;   [ex_blackin storage="room.jpg" option="white"] 4.ホワイトイン
;   [ex_blackout]                                  4.ブラックアウト
;
;   [ex_explode storage="rouka.jpg"]               5.爆発
;
;
; ＜パラメータ一覧＞
;   ■共通
;   storage(必須): 画像ファイル名を指定します。ファイルはbgimageに入れてください。
;                 ※[ex_blackout]は無し
;   time: トランジションの時間を、ミリ秒で指定します。
;
;   ■個別オプション
;   2.[ex_slide]
;     option: スライドの出現位置を指定します。left right up downが指定できます。(デフォルはleft)
;
;   3.[ex_zoomin][ex_zoomout]
;     option: 倍率を指定します。(デフォルは150)
;
;   4.[ex_blackin]
;     option: カラーを指定します。wihteでホワイトインになります。(デフォルはblack)
;
;   5.[ex_explode]
;     option: 爆発する破片の数を指定します。(デフォルは9)
;
;
; ＜注意点＞
;   ティラノスクリプトVer2.21 で動作保証
;
[macro name="ex_cross"]
  [backlay]
  [image layer="base" page="back" storage=%storage]
  [trans time=%time|1000]
  [wt]
[endmacro]

[macro name="ex_slide"]
  [backlay]
  [trans time=1]
  [wt]
  [iscript]
    $(".base_back").show();
    $(".base_fore").css({opacity:0});
  [endscript]
  [image layer=base page=fore storage=%storage]
  [wait time="100"]
  [iscript]
    if (mp.option==null) { 
      mp.option = "left";
    }
    if (mp.time==null) {
      mp.time = 1000;
    }
    $(".base_fore")
      .show("slide", {"direction":mp.option}, mp.time)
      .animate({opacity:1}, {duration:mp.time, queue:false,
        complete: function() {
          $(".base_back").hide();
          $(".base_fore").css("opacity", "");
        }
    });
    mp.time += 200;
  [endscript]
  [wait time=&mp.time]
[endmacro]

[macro name="ex_zoomin"]
  [backlay]
  [trans time=1]
  [wt]
  [wait time="100"]
  [image layer=base page=back storage=%storage]
  [iscript]
    $(".base_fore").css({"background-size":"cover","-moz-background-size":"cover"});
    $(".base_back").show();
  [endscript]
  [wait time="100"]
  [iscript]
    if (mp.option==null) { 
      mp.option = 150;
    }
    if (mp.time==null) {
      mp.time = 1000;
    }
    $(".base_fore").hide("puff", {"percent":mp.option,
      complete: function() {
        $(".base_fore").css({"background-size":"", "-moz-background-size":""});
      }}, mp.time);
    mp.time += 300;
  [endscript]
  [wait time=&mp.time]
  [image layer=base page=fore storage=%storage]
  [iscript]
    $(".base_fore").show();
    $(".base_back").hide();
  [endscript]
[endmacro]
[macro name="ex_zoomout"]
  [backlay]
  [trans time=1]
  [wt]
  [wait time="100"]
  [iscript]
    $(".base_fore").css({"background-size":"cover","-moz-background-size":"cover"});
    $(".base_back").show();
    $(".base_fore").hide();
  [endscript]
  [image layer=base page=fore storage=%storage]
  [iscript]
    if (mp.option==null) { 
      mp.option = 150;
    }
    if (mp.time==null) {
      mp.time = 1000;
    }
    $(".base_fore").show("puff", {"percent":mp.option,
      complete: function() {
        $(".base_fore").css({"background-size":"", "-moz-background-size":""});
      }}, mp.time);
    mp.time += 200;
  [endscript]
  [wait time=&mp.time]
  [iscript]
    $(".base_back").hide();
  [endscript]
[endmacro]

[macro name="ex_blackin"]
  [backlay]
  [image layer="base" page="back" storage=%storage]
  [image layer="base" page="fore" storage=""]
  [iscript]
    if (mp.option == null) {
      mp.option = "black";
    }
    $(".base_fore").css({"background-color":mp.option});
  [endscript]
  [trans time=%time|1000]
  [wt]
  [iscript]
    $(".base_fore").css({"background-color":""});
  [endscript]
[endmacro]
[macro name="ex_blackout"]
  [backlay]
  [image layer="base" page="back" storage=""]
  [trans time=%time|1000]
  [wt]
[endmacro]

[macro name="ex_explode"]
  [backlay]
  [trans time=1]
  [wt]
  [image layer=base page=back storage=%storage]
  [wait time="100"]
  [iscript]
    $(".base_back").show();
    if (mp.option==null) { 
      mp.option = 9;
    }
    if (mp.time==null) {
      mp.time = 1000;
    }
    $(".base_fore").hide("explode", {"pieces":mp.option}, mp.time);
    mp.time += 200;
  [endscript]
  [wait time=&mp.time]
  [image layer=base page=fore storage=%storage]
  [iscript]
    $(".base_fore").show();
    $(".base_back").hide();
  [endscript]
[endmacro]

[macro name="ex_blind"]
[endmacro]

[macro name="ex_clip"]
[endmacro]

[macro name="ex_cutin"]
[endmacro]
